<?php

namespace Bixo\Description\Http\Controllers;

use App\Http\Controllers\Controller as BaseController;
use Bixo\Description\Http\Requests\DescriptionRequest;
use Bixo\Description\Models\Description;

/**
 * Admin web controller class.
 */
class DescriptionWorkflowController extends BaseController
{

    /**
     * Workflow controller function for description.
     *
     * @param Model   $description
     * @param step    next step for the workflow.
     *
     * @return Response
     */

    public function putWorkflow(DescriptionRequest $request, Description $description, $step)
    {

        try {

            $description->updateWorkflow($step);

            return response()->json([
                'message'  => trans('messages.success.changed', ['Module' => trans('description::description.name'), 'status' => trans("app.{$step}")]),
                'code'     => 204,
                'redirect' => trans_url('/admin/description/description/' . $description->getRouteKey()),
            ], 201);

        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 400,
                'redirect' => trans_url('/admin/description/description/' . $description->getRouteKey()),
            ], 400);

        }

    }

    /**
     * Workflow controller function for description.
     *
     * @param Model   $description
     * @param step    next step for the workflow.
     * @param user    encrypted user id.
     *
     * @return Response
     */

    public function getWorkflow(Description $description, $step, $user)
    {
        try {
            $user_id = decrypt($user);

            Auth::onceUsingId($user_id);

            $description->updateWorkflow($step);

            $data = [
                'message' => trans('messages.success.changed', ['Module' => trans('description::description.name'), 'status' => trans("app.{$step}")]),
                'status'  => 'success',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('description::admin.description.message', $data)->render();

        } catch (ValidationException $e) {

            $data = [
                'message' => '<b>' . $e->getMessage() . '</b> <br /><br />' . implode('<br />', $e->validator->errors()->all()),
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('description::admin.description.message', $data)->render();

        } catch (Exception $e) {

            $data = [
                'message' => '<b>' . $e->getMessage() . '</b>',
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('description::admin.description.message', $data)->render();

        }

    }
}
