<?php

namespace Bixo\Description\Workflow;

use Exception;
use Litepie\Workflow\Exceptions\WorkflowActionNotPerformedException;

use Bixo\Description\Models\Description;

class DescriptionAction
{
    /**
     * Perform the complete action.
     *
     * @param Description $description
     *
     * @return Description
     */
    public function complete(Description $description)
    {
        try {
            $description->status = 'complete';
            return $description->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the verify action.
     *
     * @param Description $description
     *
     * @return Description
     */public function verify(Description $description)
    {
        try {
            $description->status = 'verify';
            return $description->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the approve action.
     *
     * @param Description $description
     *
     * @return Description
     */public function approve(Description $description)
    {
        try {
            $description->status = 'approve';
            return $description->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the publish action.
     *
     * @param Description $description
     *
     * @return Description
     */public function publish(Description $description)
    {
        try {
            $description->status = 'publish';
            return $description->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the archive action.
     *
     * @param Description $description
     *
     * @return Description
     */
    public function archive(Description $description)
    {
        try {
            $description->status = 'archive';
            return $description->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the unpublish action.
     *
     * @param Description $description
     *
     * @return Description
     */
    public function unpublish(Description $description)
    {
        try {
            $description->status = 'unpublish';
            return $description->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }
}
