<?php

namespace Bixo\Description\Workflow;

use Bixo\Description\Models\Description;
use Validator;

class DescriptionValidator
{

    /**
     * Determine if the given description is valid for complete status.
     *
     * @param Description $description
     *
     * @return bool / Validator
     */
    public function complete(Description $description)
    {
        return Validator::make($description->toArray(), [
            'title' => 'required|min:15',
        ]);
    }

    /**
     * Determine if the given description is valid for verify status.
     *
     * @param Description $description
     *
     * @return bool / Validator
     */
    public function verify(Description $description)
    {
        return Validator::make($description->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:complete',
        ]);
    }

    /**
     * Determine if the given description is valid for approve status.
     *
     * @param Description $description
     *
     * @return bool / Validator
     */
    public function approve(Description $description)
    {
        return Validator::make($description->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:verify',
        ]);

    }

    /**
     * Determine if the given description is valid for publish status.
     *
     * @param Description $description
     *
     * @return bool / Validator
     */
    public function publish(Description $description)
    {
        return Validator::make($description->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,archive,unpublish',
        ]);

    }

    /**
     * Determine if the given description is valid for archive status.
     *
     * @param Description $description
     *
     * @return bool / Validator
     */
    public function archive(Description $description)
    {
        return Validator::make($description->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,publish,unpublish',
        ]);

    }

    /**
     * Determine if the given description is valid for unpublish status.
     *
     * @param Description $description
     *
     * @return bool / Validator
     */
    public function unpublish(Description $description)
    {
        return Validator::make($description->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:publish',
        ]);

    }
}
